#!/bin/bash

source install_library.bash
source sources.bash

echo Using ARCHIVE=$ARCHIVE
cd $ARCHIVE

# Basic stuff
install_packages build-essential kernel-package

# Name of the kernel source archive
TARC=/usr/src/${LINUX_SOURCE_NAME}.tar.bz2

# Are we using the Ubuntu packaged kernel source?
if test $LINUX_SOURCE_PKG ; then
    # Install kernel source package
    [ -e "$TARC" ] || nstall_packages $LINUX_SOURCE_PKG
else
    # Download kernel source
    archive=`http_dest $LINUX_SOURCE_URL`
    archive_basename=`basename $archive`
    if [ -e "$TARC" ]; then
	echo "Destination location $TARC already exists, skipping download."
    else
	if [ -e "$archive_basename" ]; then
	    echo "Kernel source basename is here already, moving it..."
	else
	    echo "Getting kernel basename, $LINUX_SOURCE_URL."
	    get_http $LINUX_SOURCE_URL > /dev/null
	    [ -e "$archive_basename" ] || exit 1
	fi
        # Move to compilation area
	$SUDO mv "$archive" "$TARC"
    fi
fi

# Get patch if it doesn't already exist
PATCHNAME="${BIGPHYSPATCH_URL##*/}"
[ -e "$PATCHNAME" ] || get_http $BIGPHYSPATCH_URL || exit 1

KBASE=`uname -r`
KROOT=${KBASE%%-*}

echo $LINUX_SOURCE_NAME
if [ "$LINUX_SOURCE_NAME" == "" ]; then
    LINUX_SOURCE_NAME=linux-source-${KROOT}
fi

echo $TARC
if ! [ -e "$TARC" ]; then
    echo "Make LINUX_SOURCE_NAME match the archive in /usr/src."
    exit 1
fi

DEST=$ARCHIVE/${LINUX_SOURCE_NAME}

if [ -e $DEST ]; then
    echo $DEST exists, skipping extraction.
else
    echo "Untarring $TARC to $DEST (I think)"
    tar -xjf $TARC 
fi

# Go into kernel source tree.
cd $DEST

# Apply patch
PATCHOPTS="--forward -p1 -i ${ARCHIVE}/$PATCHNAME"
if patch $PATCHOPTS --dry-run; then
    patch $PATCHOPTS
else
    echo "Patch will not go gently, go manual."
    exit 1
fi

case "$DEFAULT_CONFIG" in
    copy)
	# Copy current system kernel configuration
	CONFIG=/boot/config-$KBASE
	cp $CONFIG .config
	;;
    new)
	# Run menuconfig; user should just 
	make menuconfig
	;;
    *)
	# Ok, we'll use that.
	cp "$DEFAULT_CONFIG" .config
	;;
esac

# Append the bigphys switch.
echo "CONFIG_BIGPHYS_AREA=y" >> .config

# Build
fakeroot make-kpkg clean
fakeroot make-kpkg --initrd kernel-image kernel-headers --append-to-version=-bigphys
